Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AddOrdinalValuesCommand ¶
type AddOrdinalValuesCommand struct {
// The ordinal position of the value
Ordinal int
// The stream for which the value is to be added
Stream string
// The value to be added to the stream
Value float64
PrettyPrint bool
}
AddOrdinalValuesCommand is the command line data structure for the add action of OrdinalValues
func (*AddOrdinalValuesCommand) RegisterFlags ¶
func (cmd *AddOrdinalValuesCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.
type PushOrdinalValuesCommand ¶
PushOrdinalValuesCommand is the command line data structure for the push action of OrdinalValues
func (*PushOrdinalValuesCommand) RegisterFlags ¶
func (cmd *PushOrdinalValuesCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.
type RegisterOrdinalValuesCommand ¶
RegisterOrdinalValuesCommand is the command line data structure for the register action of OrdinalValues
func (*RegisterOrdinalValuesCommand) RegisterFlags ¶
func (cmd *RegisterOrdinalValuesCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.
type StatisticsOrdinalValuesCommand ¶
StatisticsOrdinalValuesCommand is the command line data structure for the statistics action of OrdinalValues
func (*StatisticsOrdinalValuesCommand) RegisterFlags ¶
func (cmd *StatisticsOrdinalValuesCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.
type TagOrdinalValuesCommand ¶
TagOrdinalValuesCommand is the command line data structure for the tag action of OrdinalValues
func (*TagOrdinalValuesCommand) RegisterFlags ¶
func (cmd *TagOrdinalValuesCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.